==> haskell-filelock-0.1.1.5-54-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filelock
version:              0.1.1.5
visibility:           public
id:                   filelock-0.1.1.5-C89VU8Sp9MO89OvH82QPmL
key:                  filelock-0.1.1.5-C89VU8Sp9MO89OvH82QPmL
license:              LicenseRef-PublicDomain
maintainer:           tak@anoak.io
author:               Takano Akio
homepage:             http://github.com/takano-akio/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  76243b6c631f782f8e6c6237c646ff2b
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-8.10.3/site-local/filelock-0.1.1.5
library-dirs:         /usr/lib/ghc-8.10.3/site-local/filelock-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/filelock-0.1.1.5
hs-libraries:         HSfilelock-0.1.1.5-C89VU8Sp9MO89OvH82QPmL
depends:              base-4.14.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-filelock-0.1.1.5-58-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-filelock.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 filelock
version:              0.1.1.5
visibility:           public
id:                   filelock-0.1.1.5-ENk1b0XyzfnByR7rvLyLdx
key:                  filelock-0.1.1.5-ENk1b0XyzfnByR7rvLyLdx
license:              LicenseRef-PublicDomain
maintainer:           tak@anoak.io
author:               Takano Akio
homepage:             http://github.com/takano-akio/filelock
synopsis:             Portable interface to file locking (flock / LockFileEx)
description:
    This package provides an interface to Windows and Unix
    file locking functionalities.

category:             System
abi:                  a9e4e24ea0646ab3e783a811c7ceca32
exposed:              True
exposed-modules:      System.FileLock
hidden-modules:
    System.FileLock.Internal.Flock System.FileLock.Internal.LockFileEx

import-dirs:          /usr/lib/ghc-8.10.4/site-local/filelock-0.1.1.5
library-dirs:         /usr/lib/ghc-8.10.4/site-local/filelock-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/filelock-0.1.1.5
hs-libraries:         HSfilelock-0.1.1.5-ENk1b0XyzfnByR7rvLyLdx
depends:              base-4.14.1.0 unix-2.7.2.2
haddock-interfaces:   /usr/share/doc/haskell-filelock/html/filelock.haddock
haddock-html:         /usr/share/doc/haskell-filelock/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
